@@ -1,3 +1,5 @@
+import json
+
 class _AppAnalysisConstants:
 
     _PERMISSION_SIGNATURE = [
@@ -124,6 +126,29 @@ class _AppAnalysisConstants:
 
 class _Trackers:
 
+	@classmethod
+	def exodus_trackers(self, trackers):
+		"""
+		Use this method to override the build in _TRACKERS constant with 
+		the response body from the exodus api. This is not recommended because 
+		some of the detection regex's from exodus are not valid. Example 'CrowdTangle': '.' 
+		The Exodus api url is https://reports.exodus-privacy.eu.org/api/trackers
+		
+		Parameters
+		----------
+		trackers : str
+			the json response body from the exodus api.
+
+		Examples
+		--------
+		>>> import requests
+		>>> from glorifiedgrep.android.modules.constants import _Trackers
+		>>> res = requests.get('https://reports.exodus-privacy.eu.org/api/trackers').text
+		>>> _Trackers().exodus_trackers(res)
+		"""
+		data = json.loads(trackers)['trackers']
+		self._TRACKERS = {data[k]['name']: data[k]['code_signature'] for k in data}
+
 	_AD_NETWORKS = {
 		'Admob': r'^import.+google.+ads.+',
 		'Facebook': r'^import com.facebook.ads.*',
@@ -270,158 +295,212 @@ class _Trackers:
 	}
 
 	_TRACKERS = {
-        'AccountKit': 'com.facebook.accountkit',
-        'Ad4Screen': 'com.ad4screen.sdk',
-        'AdColony': 'com.adcolony',
-        'Add Apt Tr': 'com.intentsoftware.addapptr.',
-        'AdFit': 'com.kakao.adfit.ads.',
-        'AdForm': 'com.adform.sdk.',
-        'Adfurikun': 'jp.tjkapp.adfurikunsdk.',
-        'Adjust': 'com.adjust.sdk.',
-        'AdsWizz': '.adswizz.',
-        'Alphonso': 'tv.alphonso.service',
-        'Amazon Advertisement': 'com.amazon.device.ads',
-        'Amazon Analytics': 'com.amazon.insights',
-        'Amazon Mobile Associates': 'com.amazon.device.associates',
-        'Amplitude': 'com.amplitude.',
-        'AppAnalytics': 'io.appanalytics.sdk',
-        'AppBrain': 'com.appbrain',
-        'Applause': 'com.applause.android.',
-        'AppLovin': 'com.applovin',
-        'AppMetrica': 'com.yandex.metrica.',
-        'AppNexus': 'com.appnexus.opensdk.',
-        'AppSee': 'com.appsee.',
-        'AppsFlyer': 'com.appsflyer.',
-        'Apptentive': 'com.apptentive.',
-        'Apteligent by VMWare': 'com.crittercism.app.Crittercism',
-        'Apptimize': 'com.apptimize.',
-        'Areametrics': 'com.areametrics.areametricssdk',
-        'ATInternet': 'com.atinternet.',
-        'Avocarrot': 'com.avocarrot.sdk',
-        'Backelite': 'com.backelite.android.|com.backelite.bkdroid.',
-        'Baidu APPX': 'com.baidu.appx',
-        'Baidu Location': 'com.baidu.location',
-        'Baidu Map': 'com.baidu.mapapi',
-        'Baidu Maps': 'com.baidu.BaiduMap',
-        'Baidu Mobile Ads': 'com.baidu.mobads',
-        'Baidu Mobile Stat': 'com.baidu.mobstat',
-        'Baidu Navigation': 'com.baidu.navi',
-        'Batch': 'com.batch.android.',
-        'Braze': 'com.appboy',
-        'BlueConic': 'com.blueconic',
-        'BlueKai': 'com.bluekai.sdk.',
-        'Carnival': 'com.carnival.sdk, com.carnivalmobile',
-        'ChartBoost': 'com.chartboost.sdk.',
-        'Colocator': 'net.crowdconnected.androidcolocator',
-        'ComScore': 'com.comscore.',
-        'Countly': 'ly.count.android.',
-        'CrowdTangle': 'crowdtangle',
-        'Cuebiq': 'com.cuebiq.cuebiqsdk.model.Collector|com.cuebiq.cuebiqsdk.receiver.CoverageReceiver',
-        'Demdex': 'com.adobe.mobile.Analytics',
-        'Dynamic Yield': 'com.dynamicyield.',
-        'Dynatrace': 'com.dynatrace.android.app.',
-        'Ensighten': 'com.ensighten.',
-        'Estimote': 'com.estimote.',
-        'Eulerian': 'com.eulerian.android.sdk',
-        'ExactTarget': 'com.exacttarget.',
-        'Facebook Ads': 'com.facebook.ads',
-        'Facebook Analytics': 'com.facebook.appevents',
-        'Facebook Audience': 'com.facebook.audiencenetwork',
-        'Facebook Login': 'com.facebook.login',
-        'Facebook Notifications': 'com.facebook.notifications',
-        'Facebook Places': 'com.facebook.places',
-        'Facebook Share': 'com.facebook.share',
-        'Foresee': 'com.foresee.sdk.ForeSee',
-        'FidZup': 'com.fidzup.',
-        'Fiksu': 'com.fiksu.asotracking',
-        'Flurry': 'com.flurry.',
-        'Fyber': 'com.fyber.',
-        'Fyber SponsorPay': 'com.sponsorpay',
-        'Gigya': 'com.gigya.',
-        'Google Ads': 'com.google.android.gms.ads.mediation.',
-        'Google Analytics': 'com.google.android.apps.analytics.|com.google.android.gms.analytics.',
-        'Google CrashLytics': 'io.fabric.|com.crashlytics.',
-        'Google DoubleClick': 'com.google.android.gms.ads.doubleclick',
-        'Google Firebase Analytics': 'com.google.firebase.analytics.|com.google.android.gms.measurement.',
-        'Google Tag Manager': 'com.google.tagmanager',
-        'HelpShift': 'com.helpshift',
-        'Heyzap': 'com.heyzap.sdk.ads.',
-        'HockeyApp': 'net.hockeyapp.',
-        'HyperTrack': 'com.hypertrack|com.hypertracklive.|io.hypertrack',
-        'Inmobi': 'com.inmobi',
-        'Inrix': 'com.inrix.sdk',
-        'ironSource': 'com.ironsource.',
-        'JWPLTx': 'jwpltx',
-        'Kochava': 'com.kochava.android.tracker.',
-        'Kontakt': 'com.kontakt.sdk.android.',
-        'Krux': 'com.krux.androidsdk',
-        'LeanPlum': 'com.leanplum.',
-        'Ligatus': '.LigatusManager|.LigatusViewClient',
-        'Lisnr': 'com.lisnr.',
-        'Localytics': 'com.localytics.android.',
-        'Locuslabs': 'com.locuslabs.sdk',
-        'Loggly': 'com.visiware.sync2ad.logger.loggly.',
-        'MAdvertise': 'com.mngads.sdk|com.mngads.views|com.mngads.',
-        'Matomo (Piwik)': 'org.piwik|org.piwik.mobile|org.matomo',
-        'Millennial Media': 'com.millennialmedia.',
-        'MixPanel': 'com.mixpanel.',
-        'Moat': 'com.moat.analytics.mobile.',
-        'Mobile Engagement': 'com.ubikod.capptain.|com.microsoft.azure.engagement.',
-        'MParticle': 'com.mparticle',
-        'NativeX': 'com.nativex',
-        'New Relic': 'om.newrelic.agent.',
-        'Nexage': 'com.nexage.android.|org.nexage.',
-        'Ogury Presage': 'io.presage.',
-        'Omniture': 'com.omniture.|com.adobe.adms.measurement.',
-        'OutBrain': 'com.outbrain.',
-        'PushWoosh': 'com.pushwoosh',
-        'Quantcast': 'com.quantcast.measurement.service.',
-        'Radius Networks': 'com.radiusnetworks',
-        'Retency': 'com.retency.sdk.android',
-        'Rubicon Project': 'com.rfm.sdk',
-        'S4M': '/s4m/',
-        'Safe Graph': 'com.safegraph.|com.openlocate',
-        'Scandit': 'com.scandit.',
-        'Schibsted': '.schibsted.',
-        'Score Card Research': 'com.optimizely',
-        'Segment': 'com.segment.analytics.',
-        'Sense360': 'com.sense360.android.quinoa.lib.Sense360',
-        'Sensoro': 'com.sensoro.beacon.kit.|com.sensoro.cloud',
-        'Shopkick': 'com.shopkick.sdk.api.|com.shopkick.fetchers.',
-        'Signal360': 'com.signal360.sdk.core.|com.sonicnotify.sdk.core.|com.rnsignal360',
-        'SilverPush': 'com.silverpush.|com.silverpush.location|com.silverpush.sdk.android.SPService',
-        'Singlespot': 'com.sptproximitykit.',
-        'Sizmek': '.sizmek.',
-        'Smaato': 'com.smaato.soma.',
-        'Smart': 'com.smartadserver.',
-        'Snowplow': 'com.snowplowanalytics.',
-        'Supersonic Ads': 'com.supersonic.adapters.supersonicads|com.supersonicads.sdk',
-        'Sync2Ad': 'com.visiware.sync2ad.dmp.',
-        'Tag Commander': 'com.tagcommander.',
-        'Tealium': '.tealium.',
-        'Tecent Stats': 'com.tencent.stat',
-        'Teemo': 'com.databerries.',
-        'TeleQuid': 'com.telequid.',
-        'Tencent Map LBS': 'com.tencent.lbs',
-        'Tencent MobWin': 'com.tencent.mobwin',
-        'Tencent MTA': 'com.tencent.mta',
-        'Tencent Weiyun': 'com.tencent.weiyun',
-        'Tinder Analytics': 'com.tinder.analytics|com.tinder.ads',
-        'Tune': 'com.tune|com.mobileapptracker',
-        'Twitter MoPub': 'com.mopub.mobileads.',
-        'Uber Analytics': 'com.ubercab.analytics.|com.ubercab.library.metrics.analytics.|com.ubercab.client.core.analytics.',
-        'Ultimedia': 'ultimedia',
-        'Umeng Analytics': 'com.umeng.analytics',
-        'Umeng Feedback': 'com.umeng.fb',
-        'Unity3d Ads': 'com.unity3d.ads',
-        'Urbanairship': 'com.urbanairship',
-        'Vectaury': 'io.vectaury.',
-        'Weborama': 'com.weborama.',
-        'Webtrends': 'com.webtrends.mobile.analytics.|com.webtrends.mobile.android',
-        'WeChat Location': 'com.tencent.map.geolocation|com.tencent.mm.plugin.location.|com.tencent.mm.plugin.location_soso.|com.tencent.mm.plugin.location_google',
-        'Widespace': 'widespace',
-        'Xiti': 'xiti',
-        'Yandex Ad': 'com.yandex.mobile.ads',
+        # Updated 7/5/2019
+        'ADLIB': 'com.mocoplex.adlib.',
+		'ATInternet': 'com.atinternet.',
+		'AccountKit': 'com.facebook.accountkit',
+		'Ad4Screen': 'com.ad4screen.sdk',
+		'AdColony': 'com.adcolony',
+		'AdFit (Daum)': 'com.kakao.adfit.ads.',
+		'Add Apt Tr': 'com.intentsoftware.addapptr.',
+		'Adform': 'com.adform.sdk.',
+		'Adfurikun': 'jp.tjkapp.adfurikunsdk.',
+		'Adincube': 'com.adincube.sdk.',
+		'Adjust': 'com.adjust.sdk.',
+		'Adot': 'com.adotmob',
+		'AdsWizz': '.adswizz.',
+		'AerServ': 'com.aerserv.sdk.',
+		'Alphonso': 'tv.alphonso.service',
+		'Amazon Advertisement': 'com.amazon.device.ads',
+		'Amazon Analytics': 'com.amazon.insights|com.amazonaws.mobileconnectors.pinpoint.analytics.',
+		'Amazon Mobile Associates': 'com.amazon.device.associates',
+		'Amplitude': 'com.amplitude.',
+		'AppAnalytics': 'io.appanalytics.sdk',
+		'AppBrain': 'com.appbrain.',
+		'AppLovin': 'com.applovin',
+		'AppMetrica': 'com.yandex.metrica.',
+		'AppMonet': 'com.monet.',
+		'AppNexus': 'com.appnexus.opensdk.',
+		'AppSee': 'com.appsee.',
+		'Appdynamics': 'com.appdynamics.',
+		'Applause': 'com.applause.android.',
+		'Appnext': 'com.appnext.',
+		'Appodeal': 'com.appodeal.ads.',
+		'AppsFlyer': 'com.appsflyer.',
+		'Apptentive': 'com.apptentive.',
+		'Apptimize': 'com.apptimize.',
+		'Apteligent by VMWare (formerly Crittercism)': 'com.crittercism.app.Crittercism',
+		'Areametrics': 'com.areametrics.areametricssdk|com.areametrics.nosdkandroid',
+		'Auditude': 'com.auditude.ads',
+		'Backelite': 'com.backelite.android.|com.backelite.bkdroid.',
+		'Baidu APPX': 'com.baidu.appx',
+		'Baidu Location': 'com.baidu.location',
+		'Baidu Map': 'com.baidu.mapapi',
+		'Baidu Maps': 'com.baidu.BaiduMap',
+		'Baidu Mobile Ads': 'com.baidu.mobads',
+		'Baidu Mobile Stat': 'com.baidu.mobstat',
+		'Baidu Navigation': 'com.baidu.navi',
+		'Batch': 'com.batch.android.',
+		'BlueConic': 'com.blueconic',
+		'BlueKai (acquired by Oracle)': 'com.bluekai.sdk.',
+		'Branch': 'io.branch.',
+		'Braze (formerly Appboy)': 'com.appboy',
+		'Brightcove': 'com.brightcove',
+		'Bugly': 'com.tencent.bugly.',
+		'Bugsnag': 'com.bugsnag.',
+		'Carnival': 'com.carnival.sdk|com.carnivalmobile',
+		'ChartBoost': 'com.chartboost.sdk.',
+		'Cheetah Ads': 'com.cmcm.',
+		'CleverTap': 'com.clevertap.',
+		'Cloudmobi': 'com.cloudtech.',
+		'Colocator': 'net.crowdconnected.androidcolocator',
+		'ComScore': 'com.comscore.',
+		'Conviva': 'com.conviva.',
+		'Countly': 'ly.count.android.',
+		'Criteo': 'com.criteo.',
+		# 'CrowdTangle': '.',
+		'Cuebiq': 'com.cuebiq.cuebiqsdk.model.Collector|com.cuebiq.cuebiqsdk.receiver.CoverageReceiver',
+		'DOV-E': 'com.dv.',
+		'Demdex': 'com.adobe.mobile.Analytics',
+		'Display': 'io.display.',
+		'Duapps': 'com.duapps.',
+		'Dynamic Yield': 'com.dynamicyield.',
+		'Dynatrace': 'com.dynatrace.android.app.',
+		'Ensighten': 'com.ensighten.',
+		'Estimote': 'com.estimote.',
+		'Eulerian': 'com.eulerian.android.sdk',
+		'ExactTarget': 'com.exacttarget.',
+		'Facebook Ads': 'com.facebook.ads',
+		'Facebook Analytics': 'com.facebook.appevents',
+		'Facebook Audience': 'com.facebook.audiencenetwork',
+		'Facebook Login': 'com.facebook.login',
+		'Facebook Notifications': 'com.facebook.notifications',
+		'Facebook Places': 'com.facebook.places',
+		'Facebook Share': 'com.facebook.share',
+		'FidZup': 'com.fidzup.',
+		'Fiksu': 'com.fiksu.asotracking',
+		'Flurry': 'com.flurry.',
+		'Foresee': 'com.foresee.sdk.ForeSee',
+		'Fyber': 'com.fyber.',
+		'Fyber SponsorPay': 'com.sponsorpay',
+		'GameAnalytics': 'com.gameanalytics.sdk',
+		'Gigya': 'com.gigya.',
+		'Gimbal': 'com.gimbal.android',
+		'Glispa Connect (Formerly Avocarrot)': 'com.avocarrot.sdk',
+		'Google Ads': 'com.google.android.gms.ads.mediation.',
+		'Google Analytics': 'com.google.android.apps.analytics.|com.google.android.gms.analytics.',
+		'Google CrashLytics': 'io.fabric.|com.crashlytics.',
+		'Google DoubleClick': 'com.google.android.gms.ads.doubleclick',
+		'Google Firebase Analytics': 'com.google.firebase.analytics.|com.google.android.gms.measurement.',
+		'Google Tag Manager': 'com.google.tagmanager',
+		'HelpShift': 'com.helpshift',
+		'Heyzap (bought by Fyber)': 'com.heyzap.sdk.ads.',
+		'HockeyApp': 'net.hockeyapp.',
+		'Houndify': 'com.hound',
+		'HyperTrack': 'com.hypertrack|com.hypertracklive.|io.hypertrack',
+		'HyprMX': 'com.hyprmx.android.sdk.',
+		'INFOnline': 'de.infonline.',
+		'Inmarket': 'com.inmarket',
+		'Inmobi': 'com.inmobi',
+		'Inrix': 'com.inrix.sdk',
+		'Instabug': 'com.instabug.library.tracking|com.instabug.bug',
+		'Instreamatic': 'com.instreamatic',
+		'JW Player': 'com.longtailvideo.jwplayer.',
+		'Kochava': 'com.kochava.base.Tracker|com.kochava.android.tracker.',
+		'Kontakt': 'com.kontakt.sdk.android.',
+		'Krux': 'com.krux.androidsdk',
+		'LeanPlum': 'com.leanplum.',
+		'Ligatus': '.LigatusManager|.LigatusViewClient|com.ligatus.android.adframework',
+		'Lisnr': 'com.lisnr.',
+		'Localytics': 'com.localytics.android.',
+		'Locuslabs': 'com.locuslabs.sdk',
+		'Loggly': 'com.github.tony19.timber.loggly|com.github.tony19.loggly|com.visiware.sync2ad.logger.loggly.',
+		'MAdvertise': 'com.mngads.sdk|com.mngads.views|com.mngads.',
+		'MParticle': 'com.mparticle',
+		'Mapbox': 'com.mapbox.mapboxsdk.',
+		'Matomo (Piwik)': 'org.piwik|org.piwik.mobile|org.matomo',
+		'Millennial Media': 'com.millennialmedia.',
+		'Mintegral': 'com.mintegral.',
+		'MixPanel': 'com.mixpanel.',
+		'Moat': 'com.moat.analytics.mobile.',
+		'MobFox': 'com.mobfox.',
+		'Mobile Engagement': 'com.ubikod.capptain.|com.microsoft.azure.engagement.',
+		'Mobvista': 'com.mobvista.',
+		'Moodmedia': 'com.moodmedia',
+		'NativeX': 'com.nativex',
+		'New Relic': 'com.newrelic.agent.',
+		'Nexage': 'com.nexage.android.|org.nexage.',
+		'Ogury Presage': 'io.presage.',
+		'Omniture': 'com.omniture.|com.adobe.adms.measurement.',
+		'OneSignal': 'com.onesignal.',
+		'Ooyala': 'com.ooyala',
+		'OpenX': 'com.openx.view.plugplay|com.openx.android_sdk_openx',
+		'Optimizely': 'com.optimizely.',
+		'OtherLevels': 'com.otherlevels.',
+		'OutBrain': 'com.outbrain.',
+		'Persona.ly': 'ly.persona.sdk',
+		'Pilgrim': 'com.foursquare.pilgrim|com.foursquare.pilgrimsdk.android',
+		'Placed': 'com.placed.client',
+		'PubNative': 'net.pubnative',
+		'Pushwoosh': 'com.pushwoosh',
+		'Quantcast': 'com.quantcast.measurement.service.',
+		'Radius Networks': 'com.radiusnetworks',
+		'Retency': 'com.retency.sdk.android',
+		'Rubicon Project': 'com.rfm.sdk',
+		'S4M': 'com.sam4mobile.',
+		'Safe Graph': 'com.safegraph.|com.openlocate',
+		'Scandit': 'com.scandit.',
+		'Schibsted': '.schibsted.',
+		'Segment': 'com.segment.analytics.',
+		'Sense360': 'com.sense360.android.quinoa.lib.Sense360',
+		'Sensoro': 'com.sensoro.beacon.kit.|com.sensoro.cloud',
+		'ShallWeAD': 'com.jm.co.shallwead.sdk.|com.co.shallwead.sdk.',
+		'Shopkick': 'com.shopkick.sdk.api.|com.shopkick.fetchers.',
+		'Signal360': 'com.signal360.sdk.core.|com.sonicnotify.sdk.core.|com.rnsignal360',
+		'SilverPush': 'com.silverpush.|com.silverpush.location|com.silverpush.sdk.android.SPService',
+		'Singlespot': 'com.sptproximitykit.',
+		'Sizmek': '.sizmek.',
+		'Smaato': 'com.smaato.soma.',
+		'Smart': 'com.smartadserver.',
+		'Snowplow': 'com.snowplowanalytics.',
+		'Soomla': 'com.soomla.',
+		'Startapp': 'com.startapp.android.publish',
+		'Supersonic Ads': 'com.supersonic.adapters.supersonicads|com.supersonicads.sdk',
+		'Swrve': 'com.swrve.sdk',
+		'Sync2Ad': 'com.visiware.sync2ad.dmp.',
+		'Taboola': 'com.taboola.',
+		'Tag Commander': 'com.tagcommander.',
+		'Tapjoy': 'com.tapjoy.',
+		'Taplytics': 'com.taplytics.sdk',
+		'Tealium': '.tealium.',
+		'Teemo': 'com.databerries.|com.geolocstation.',
+		'TeleQuid': 'com.telequid.',
+		'Tencent MTA': 'com.tencent.mta',
+		'Tencent Map LBS': 'com.tencent.lbs',
+		'Tencent MobWin': 'com.tencent.mobwin',
+		'Tencent Stats': 'com.tencent.stat',
+		'Tencent Weiyun': 'com.tencent.weiyun',
+		'Tinder Analytics': 'com.tinder.analytics|com.tinder.ads',
+		'Tune': 'com.tune|com.mobileapptracker',
+		'Twitter MoPub': 'com.mopub.mobileads.',
+		'Uber Analytics': 'com.ubercab.analytics.|com.ubercab.library.metrics.analytics.|com.ubercab.client.core.analytics.',
+		'Umeng Analytics': 'com.umeng.analytics',
+		'Umeng Feedback': 'com.umeng.fb',
+		'Unity3d Ads': 'com.unity3d.services|com.unity3d.ads',
+		'Urbanairship': 'com.urbanairship',
+		'Vectaury': 'io.vectaury.',
+		'Vungle': 'com.vungle.publisher.',
+		'WeChat Location': 'com.tencent.map.geolocation|com.tencent.mm.plugin.location.|com.tencent.mm.plugin.location_soso.|com.tencent.mm.plugin.location_google',
+		'Weborama': 'com.weborama.',
+		'Webtrends': 'com.webtrends.mobile.analytics.|com.webtrends.mobile.android',
+		'Widespace': 'com.widespace.',
+		# 'Xiti': 'NC',
+		'Yandex Ad': 'com.yandex.mobile.ads',
+		'Yinzcam Sobek': 'com.yinzcam.sobek',
+		'deltaDNA': 'com.deltadna',
+		'ironSource': 'com.ironsource.',
+		'myTarget': 'com.my.target.',
+		'myTracker': 'com.my.tracker.'
     }
 
 
